==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/en_GB.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Storage not available",
    "Storage invalid" : "Storage invalid",
    "Unknown error" : "Unknown error",
    "Could not move %s - File with this name already exists" : "Could not move %s - File with this name already exists",
    "Could not move %s" : "Could not move %s",
    "Permission denied" : "Permission denied",
    "The target folder has been moved or deleted." : "The target folder has been moved or deleted.",
    "The name %s is already used in the folder %s. Please choose a different name." : "The name %s is already used in the folder %s. Please choose a different name.",
    "Error when creating the file" : "Error when creating the file",
    "Error when creating the folder" : "Error when creating the folder",
    "Unable to set upload directory." : "Unable to set upload directory.",
    "Invalid Token" : "Invalid Token",
    "No file was uploaded. Unknown error" : "No file was uploaded. Unknown error",
    "There is no error, the file uploaded with success" : "There is no error, the file uploaded successfully",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "The uploaded file exceeds the upload_max_filesize directive in php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Failed to write to disk" : "Failed to write to disk",
    "Not enough storage available" : "Not enough storage available",
    "Upload failed. Could not find uploaded file" : "Upload failed. Could not find uploaded file",
    "Upload failed. Could not get file info." : "Upload failed. Could not get file info.",
    "Invalid directory." : "Invalid directory.",
    "Files" : "Files",
    "All files" : "All files",
    "Favorites" : "Favourites",
    "Home" : "Home",
    "Close" : "Close",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Total file size {size1} exceeds upload limit {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Upload cancelled." : "Upload cancelled.",
    "Could not get result from server." : "Could not get result from server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "File upload is in progress. Leaving the page now will cancel the upload.",
    "Actions" : "Actions",
    "Download" : "Download",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Details" : "Details",
    "Select" : "Select",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "Error moving file." : "Error moving file.",
    "Error moving file" : "Error moving file",
    "Error" : "Error",
    "{new_name} already exists" : "{new_name} already exists",
    "Could not rename file" : "Could not rename file",
    "Could not create file" : "Could not create file",
    "Could not create folder" : "Could not create folder",
    "Error deleting file." : "Error deleting file.",
    "No entries in this folder match '{filter}'" : "No entries in this folder match '{filter}'",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "New" : "New",
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "Upload" : "Upload",
    "Text file" : "Text file",
    "Folder" : "Folder",
    "New folder" : "New folder",
    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
    "A new file or folder has been <strong>created</strong>" : "A new file or folder has been <strong>created</strong>",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favourite files</strong> <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "A file or folder has been <strong>deleted</strong>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
    "You created %1$s" : "You created %1$s",
    "%2$s created %1$s" : "%2$s created %1$s",
    "%1$s was created in a public folder" : "%1$s was created in a public folder",
    "You changed %1$s" : "You changed %1$s",
    "%2$s changed %1$s" : "%2$s changed %1$s",
    "You deleted %1$s" : "You deleted %1$s",
    "%2$s deleted %1$s" : "%2$s deleted %1$s",
    "You restored %1$s" : "You restored %1$s",
    "%2$s restored %1$s" : "%2$s restored %1$s",
    "%s could not be renamed as it has been deleted" : "%s could not be renamed as it has been deleted",
    "%s could not be renamed" : "%s could not be renamed",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "File handling",
    "Maximum upload size" : "Maximum upload size",
    "max. possible: " : "max. possible: ",
    "Save" : "Save",
    "Can not be edited from here due to insufficient permissions." : "Can not be edited from here due to insufficient permissions.",
    "Settings" : "Settings",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>",
    "Cancel upload" : "Cancel upload",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "Files are being scanned, please wait." : "Files are being scanned, please wait.",
    "Currently scanning" : "Currently scanning",
    "No favorites" : "No favourites",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/en_GB.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Storage not available",
    "Storage invalid" : "Storage invalid",
    "Unknown error" : "Unknown error",
    "Unable to set upload directory." : "Unable to set upload directory.",
    "Invalid Token" : "Invalid Token",
    "No file was uploaded. Unknown error" : "No file was uploaded. Unknown error",
    "There is no error, the file uploaded with success" : "There is no error, the file uploaded successfully",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "The uploaded file exceeds the upload_max_filesize directive in php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Failed to write to disk" : "Failed to write to disk",
    "Not enough storage available" : "Not enough storage available",
    "The target folder has been moved or deleted." : "The target folder has been moved or deleted.",
    "Upload failed. Could not find uploaded file" : "Upload failed. Could not find uploaded file",
    "Upload failed. Could not get file info." : "Upload failed. Could not get file info.",
    "Invalid directory." : "Invalid directory.",
    "Files" : "Files",
    "All files" : "All files",
    "Favorites" : "Favourites",
    "Home" : "Home",
    "Close" : "Close",
    "Upload cancelled." : "Upload cancelled.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Total file size {size1} exceeds upload limit {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Error uploading file \"{fileName}\": {message}" : "Error uploading file \"{fileName}\": {message}",
    "Could not get result from server." : "Could not get result from server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "File upload is in progress. Leaving the page now will cancel the upload.",
    "Actions" : "Actions",
    "Download" : "Download",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Disconnect storage" : "Disconnect storage",
    "Unshare" : "Unshare",
    "Details" : "Details",
    "Select" : "Select",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "This operation is forbidden" : "This operation is forbidden",
    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
    "Could not move \"{file}\"" : "Could not move \"{file}\"",
    "{newName} already exists" : "{newName} already exists",
    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "No entries in this folder match '{filter}'",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "New" : "New",
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Storage of {owner} is full, files can not be updated or synced anymore!",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Storage of {owner} is almost full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "Folder" : "Folder",
    "New folder" : "New folder",
    "{newname} already exists" : "{newname} already exists",
    "Upload" : "Upload",
    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
    "A new file or folder has been <strong>created</strong>" : "A new file or folder has been <strong>created</strong>",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favourite files</strong> <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "A file or folder has been <strong>deleted</strong>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
    "You created %1$s" : "You created %1$s",
    "%2$s created %1$s" : "%2$s created %1$s",
    "%1$s was created in a public folder" : "%1$s was created in a public folder",
    "You changed %1$s" : "You changed %1$s",
    "%2$s changed %1$s" : "%2$s changed %1$s",
    "You deleted %1$s" : "You deleted %1$s",
    "%2$s deleted %1$s" : "%2$s deleted %1$s",
    "You restored %1$s" : "You restored %1$s",
    "%2$s restored %1$s" : "%2$s restored %1$s",
    "Changed by %2$s" : "Changed by %2$s",
    "Deleted by %2$s" : "Deleted by %2$s",
    "Restored by %2$s" : "Restored by %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "File handling",
    "Maximum upload size" : "Maximum upload size",
    "max. possible: " : "max. possible: ",
    "Save" : "Save",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "With PHP-FPM it might take 5 minutes for changes to be applied.",
    "Missing permissions to edit from here." : "Missing permissions to edit from here.",
    "Settings" : "Settings",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>",
    "Cancel upload" : "Cancel upload",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "No favorites" : "No favourites",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
    "Text file" : "Text file",
    "New text file.txt" : "New text file.txt",
    "Changed by %2$s" : "Changed by %2$s",
    "Deleted by %2$s" : "Deleted by %2$s",
    "Restored by %2$s" : "Restored by %2$s",
    "You changed %1$s" : "You changed %1$s",
    "You created %1$s" : "You created %1$s",
    "You deleted %1$s" : "You deleted %1$s",
    "You restored %1$s" : "You restored %1$s"
},
"nplurals=2; plural=(n != 1);");
